==> querydsl-core-3.2.2-sources.jar: com/mysema/query/types/query/StringSubQuery.java <==
/*
 * Copyright 2011, Mysema Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.mysema.query.types.query;

import javax.annotation.Nullable;

import com.mysema.query.QueryMetadata;
import com.mysema.query.types.Ops;
import com.mysema.query.types.SubQueryExpressionImpl;
import com.mysema.query.types.Visitor;
import com.mysema.query.types.expr.BooleanExpression;
import com.mysema.query.types.expr.BooleanOperation;
import com.mysema.query.types.expr.StringExpression;

/**
 * String typed single result subquery
 *
 * @author tiwe
 */
public final class StringSubQuery extends StringExpression implements ExtendedSubQueryExpression<String> {

    private static final long serialVersionUID = -64156984110154969L;

    private final SubQueryExpressionImpl<String> subQueryMixin;
    
    @Nullable
    private volatile BooleanExpression exists;

    public StringSubQuery(QueryMetadata md) {
        super(new SubQueryExpressionImpl<String>(String.class, md));
        this.subQueryMixin = (SubQueryExpressionImpl<String>)mixin;
    }
    
    @Override
    public final <R,C> R accept(Visitor<R,C> v, C context) {
        return v.visit(subQueryMixin, context);
    }

    @Override
    public BooleanExpression exists() {
        if (exists == null) {
            exists = BooleanOperation.create(Ops.EXISTS, mixin);
        }
        return exists;
    }

    @Override
    public QueryMetadata getMetadata() {
        return subQueryMixin.getMetadata();
    }

    @Override
    public BooleanExpression notExists() {
        return exists().not();
    }

}

==> querydsl-core-3.3.3-sources.jar: com/mysema/query/types/query/StringSubQuery.java <==
/*
 * Copyright 2011, Mysema Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.mysema.query.types.query;

import javax.annotation.Nullable;

import com.mysema.query.QueryMetadata;
import com.mysema.query.types.Ops;
import com.mysema.query.types.SubQueryExpressionImpl;
import com.mysema.query.types.Visitor;
import com.mysema.query.types.expr.BooleanExpression;
import com.mysema.query.types.expr.BooleanOperation;
import com.mysema.query.types.expr.StringExpression;

/**
 * String typed single result subquery
 *
 * @author tiwe
 */
public final class StringSubQuery extends StringExpression implements ExtendedSubQueryExpression<String> {

    private static final long serialVersionUID = -64156984110154969L;

    private final SubQueryExpressionImpl<String> subQueryMixin;

    @Nullable
    private volatile BooleanExpression exists;

    public StringSubQuery(QueryMetadata md) {
        super(new SubQueryExpressionImpl<String>(String.class, md));
        this.subQueryMixin = (SubQueryExpressionImpl<String>)mixin;
    }

    @Override
    public <R,C> R accept(Visitor<R,C> v, C context) {
        return v.visit(subQueryMixin, context);
    }

    @Override
    public BooleanExpression exists() {
        if (exists == null) {
            exists = BooleanOperation.create(Ops.EXISTS, mixin);
        }
        return exists;
    }

    @Override
    public QueryMetadata getMetadata() {
        return subQueryMixin.getMetadata();
    }

    @Override
    public BooleanExpression notExists() {
        return exists().not();
    }

}
